pub enum Error {
CloseElement,
CloseNamespace,
OpenNamespaceWithoutElement,
WriteWithoutElement,
WriteAllEof,
ParsingUtf8,
InvalidCdata,
InvalidComment,
InvalidEncoding,
InvalidName,
InvalidAttrValue,
}Expand description
Things that may go wrong during creation of the XML.
Variants
CloseElement
Closing an elemtent without having one opened.
CloseNamespace
Closing a namespace without having one opened.
OpenNamespaceWithoutElement
Opening a namespace without having an element.
WriteWithoutElement
Attempt to write without having an element opened.
WriteAllEof
Writing the buffer failed.
ParsingUtf8
Conversion of buffer into String failed.
InvalidCdata
CDATA content contains the illegal sequence ]]>.
InvalidComment
Comment content contains the illegal sequence --.
InvalidEncoding
Encoding name is not valid per the XML specification.
InvalidName
Element or attribute name is not a valid XML name.
InvalidAttrValue
Attribute value contains a character that would produce malformed XML.
Use attr_esc to write a value containing ", <, or &.